@@ -25,9 +25,9 @@
 
 // =================================================================
 // File Name : archimedes.c
-// Version   : release 0.1.2
+// Version   : release 0.1.3
 // Date of Creation : 07 Dec.2003, Paris, France, Jean Michel Sellier
-// Last Revision : 13 September 2007, Siracusa, Italy, Jean Michel Sellier.
+// Last Revision : 14 September 2007, Siracusa, Italy, Jean Michel Sellier.
 // System of Measure : M.K.S.C. System
 // =================================================================
 
@@ -66,7 +66,7 @@
 #define MESHFORMAT 1 // output file in Mesh format
 
 // definition of the material reference table
-#define NOAMTIA 5   // Number Of All Material Taken Into Account (excluding SiO2)
+#define NOAMTIA 7   // Number Of All Material Taken Into Account (excluding SiO2)
 // ********************
 #define iSIO2 -1      // reference number to Silicon Oxide
 #define SILICON 0    // reference number to Silicon
@@ -74,6 +74,8 @@
 #define GERMANIUM 2  // reference number to Germanium
 #define INSB 3       // reference number to InSb
 #define ALSB 4       // reference number to AlSb
+#define ALXINXSB 5   // reference number to Al_x In_x Sb
+#define ALXIN1XSB 6  // reference number to Al_x In_(1-x) Sb
 // ********************
 
 #define NUMSIO2 2 // maximum number of SiO2 interfaces
@@ -149,6 +151,7 @@ real RHO[NOAMTIA+1];
 real DA[NOAMTIA+1];
 real UL[NOAMTIA+1];
 real EMIN[NOAMTIA+1][4];
+real XVAL[NOAMTIA+1];
 
 // All structures here...
 time_t binarytime;
@@ -194,7 +197,7 @@ main(int argc,char* argv[])
       if (optind < argc)
         printf("Too many arguments\n");
         printf("Try `%s --help' for more information.\n",progname);
-      exit (1);
+      exit(1);
     }
 
   /* `help' should come first.  If `help' is requested, ignore the other
@@ -233,7 +236,7 @@ Report bugs to sellier@dmi.unict.it or archimedes@southnovel.eu\n");
   if (v)
     {
       /* Print version number.  */
-      printf("archimedes - GNU archimedes 0.1.2\n");
+      printf("archimedes - GNU archimedes 0.1.3\n");
       /* xgettext: no-wrap */
       printf("\n");
       printf("\
@@ -268,6 +271,8 @@ For more information about these matters, see the file named COPYING.\n",
      NOVALLEY[GAAS]=2;
      NOVALLEY[INSB]=2;
      NOVALLEY[ALSB]=2;
+     NOVALLEY[ALXINXSB]=2;
+     NOVALLEY[ALXIN1XSB]=2;
 // Dielectric constant for Silicon Oxide SiO2
      EPSRSIO2=17.0*EPS0;
 // Dielectric constant for Semiconducting materials
@@ -276,6 +281,7 @@ For more information about these matters, see the file named COPYING.\n",
      EPSR[GAAS]=12.90*EPS0;
      EPSR[INSB]=17.65*EPS0;
      EPSR[ALSB]=12.04*EPS0;
+
 // III-V semiconductor compounds high frequency dieletric constant
      EPF[GAAS]=10.92;
      EPF[INSB]=15.68;
@@ -425,6 +431,55 @@ For more information about these matters, see the file named COPYING.\n",
      alphaK[ALSB][2]=pow(1.-MSTAR[ALSB][2],2.)/(EG[ALSB]+EMIN[ALSB][2]);//0.135;
      printf("alphaK_L[AlSb]     = %g\n",alphaK[ALSB][2]);
 
+// Semiconductor compounds
+// ***
+// Relative dielectric constant for semiconductor compounds
+     EPSR[ALXINXSB]=XVAL[ALXINXSB]*EPSR[ALSB]+XVAL[ALXINXSB]*EPSR[INSB];
+     EPSR[ALXIN1XSB]=XVAL[ALXIN1XSB]*EPSR[ALSB]+(1.-XVAL[ALXIN1XSB])*EPSR[INSB];
+// semiconductor compounds high frequency dieletric constant
+     EPF[ALXINXSB]=XVAL[ALXINXSB]*(EPF[ALSB]+EPF[INSB]);
+     EPF[ALXIN1XSB]=XVAL[ALXIN1XSB]*EPF[ALSB]+(1.-XVAL[ALXIN1XSB])*EPF[INSB];
+// semiconductor compounds optical phonon scattering energy (eV)
+     HWO[ALXINXSB][0]=XVAL[ALXINXSB]*(HWO[ALSB][0]+HWO[INSB][0]);
+     HWO[ALXIN1XSB][0]=XVAL[ALXIN1XSB]*HWO[ALSB][0]+(1.-XVAL[ALXIN1XSB])*HWO[INSB][0];
+// semiconductor compounds optical coupling constants (eV/m)
+     DTK[ALXINXSB][0]=XVAL[ALXINXSB]*(DTK[ALSB][0]+DTK[INSB][0]);
+     DTK[ALXIN1XSB][0]=XVAL[ALXIN1XSB]*DTK[ALSB][0]+(1.-XVAL[ALXIN1XSB])*DTK[INSB][0];
+// semiconductor compounds optical phonon Z-factor
+     ZF[ALXINXSB][0]=XVAL[ALXINXSB]*(ZF[ALSB][0]+ZF[INSB][0]);
+     ZF[ALXIN1XSB][0]=XVAL[ALXIN1XSB]*ZF[ALSB][0]+(1.-XVAL[ALXIN1XSB])*ZF[INSB][0];
+// semiconductor compounds Crystal Density (Kg/m^3)
+     RHO[ALXINXSB]=XVAL[ALXINXSB]*(RHO[ALSB]+RHO[INSB]);
+     RHO[ALXIN1XSB]=XVAL[ALXIN1XSB]*RHO[ALSB]+(1.-XVAL[ALXIN1XSB])*RHO[INSB];
+// semiconductor compounds acoustic deformation potential (Joule)
+     DA[ALXINXSB]=XVAL[ALXINXSB]*(DA[ALSB]+DA[INSB]);
+     DA[ALXIN1XSB]=XVAL[ALXIN1XSB]*DA[ALSB]+(1.-XVAL[ALXIN1XSB])*DA[INSB];
+// semiconductor compounds longitudinal sound velocity (m/sec)
+     UL[ALXINXSB]=XVAL[ALXINXSB]*(UL[ALSB]+UL[INSB]);
+     UL[ALXIN1XSB]=XVAL[ALXIN1XSB]*UL[ALSB]+(1.-XVAL[ALXIN1XSB])*UL[INSB];
+// semiconductor compounds energy gap
+     EG[ALXINXSB]=XVAL[ALXINXSB]*(EG[ALSB]+EG[INSB]);
+     EG[ALXIN1XSB]=XVAL[ALXIN1XSB]*EG[ALSB]+(1.-XVAL[ALXIN1XSB])*EG[INSB];
+// semiconductor compounds energy minimum of GAMMA-valley
+     EMIN[ALXINXSB][1]=XVAL[ALXINXSB]*(EMIN[ALSB][1]+EMIN[INSB][1]);
+     EMIN[ALXIN1XSB][1]=XVAL[ALXIN1XSB]*EMIN[ALSB][1]+(1.-XVAL[ALXIN1XSB])*EMIN[INSB][1];
+// semiconductor compounds energy minimum 0f L-valley
+     EMIN[ALXINXSB][2]=XVAL[ALXINXSB]*(EMIN[ALSB][2]+EMIN[INSB][2]);
+     EMIN[ALXIN1XSB][2]=XVAL[ALXIN1XSB]*EMIN[ALSB][2]+(1.-XVAL[ALXIN1XSB])*EMIN[INSB][2];
+// GAMMA-valley effective mass
+     MSTAR[ALXINXSB][1]=XVAL[ALXINXSB]*(MSTAR[ALSB][1]+MSTAR[INSB][1]);
+     MSTAR[ALXIN1XSB][1]=XVAL[ALXIN1XSB]*MSTAR[ALSB][1]+(1.-XVAL[ALXIN1XSB])*MSTAR[INSB][1];
+// L-valley effective mass
+     MSTAR[ALXINXSB][2]=XVAL[ALXINXSB]*(MSTAR[ALSB][2]+MSTAR[INSB][2]);
+     MSTAR[ALXIN1XSB][2]=XVAL[ALXIN1XSB]*MSTAR[ALSB][2]+(1.-XVAL[ALXIN1XSB])*MSTAR[INSB][2];
+// non-parabolicity coefficient for semiconductor compounds in the GAMMA-valley
+     alphaK[ALXINXSB][1]=XVAL[ALXINXSB]*(alphaK[ALSB][1]+alphaK[INSB][1]);
+     alphaK[ALXIN1XSB][1]=XVAL[ALXIN1XSB]*alphaK[ALSB][1]+(1.-XVAL[ALXIN1XSB])*alphaK[INSB][1];
+// non-parabolicity coefficient for Al_x In_(1-x) Sb in the L-valley
+     alphaK[ALXINXSB][2]=XVAL[ALXINXSB]*(alphaK[ALSB][2]+alphaK[INSB][2]);
+     alphaK[ALXIN1XSB][2]=XVAL[ALXIN1XSB]*alphaK[ALSB][2]+(1.-XVAL[ALXIN1XSB])*alphaK[INSB][2];
+// ***
+
 // Closure of the input file
 // =========================
      fclose(fp);
