@@ -1,4 +1,4 @@
-/* readinputfile.h -- This file is part of Archimedes release 0.1.2
+/* readinputfile.h -- This file is part of Archimedes release 0.1.3
    Archimedes is a simulator for Submicron 2D III-V semiconductor
    Devices. It implements the Monte Carlo method and Hybrid MEP model
    for the simulation of the semiclassical Boltzmann equation for both
@@ -25,13 +25,13 @@
 
 // ######################################################
 // Created on 10 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 12 september 2007, Catania, J.M.Sellier
+// Last modif. : 14 september 2007, Siracusa, J.M.Sellier
 // ######################################################
 
 // Read the geometrical and physical description of the device.
 // The input file is interpreted as in a script language.
 // For the syntax of the commands of this language see
-// the manual GNU Archimedes release 0.1.2
+// the manual GNU Archimedes release 0.1.3
 
 void
 Read_Input_File(void)
@@ -48,6 +48,7 @@ Read_Input_File(void)
 // in the input file we have
 // the following values.
 // ============================
+ XVAL[ALXINXSB]=XVAL[ALXIN1XSB]=0.5;
  Model_Number=MCE; // here we choose the model
  nx=50; // default # of cells in x-direction
  ny=50; // default # of cells in y-direction
@@ -124,6 +125,30 @@ Processing the input file\n\
     }
     else if(strcmp(s,"INSB")==0) type=INSB;
     else if(strcmp(s,"ALSB")==0) type=ALSB;
+    else if(strcmp(s,"ALxINxSB")==0){
+      real dum;
+      type=ALXINXSB;
+      fscanf(fp,"%lf",&dum);
+      XVAL[type]=dum;
+      if(XVAL[type]<0.){
+        printf("%s : x negative for AlxInxSb!\n",progname);
+        exit(0);
+      }
+      XVAL[type]=dum;
+      printf("AlxInxSb X = %g\n",XVAL[type]);
+    }
+    else if(strcmp(s,"ALxIN1-xSB")==0){
+      real dum;
+      type=ALXIN1XSB;
+      fscanf(fp,"%lf",&dum);
+      XVAL[type]=dum;
+      if(XVAL[type]<0.){
+        printf("%s : x negative for AlxIn(1-x)Sb!\n",progname);
+        exit(0);
+      }
+      XVAL[type]=dum;
+      printf("AlxIn(1-x)Sb X = %g\n",XVAL[type]);
+    }
     else{
       printf("%s : unknown specified material!\n",progname);
       exit(0);
